package de.hdm_stuttgart.mi.sd1.task1;


/**
 * Surrounding a text block by a frame
 */
public class D_Frame {

    /**
     * <p>Surround a sequence of lines by a rectangular text frame.</p>
     *
     * <p>Consider the following example array of text lines:</p>
     *
     * <pre><code class="java">String[] lines = {"This is", "just", "a couple of lines"};</code></pre>
     *
     * <p>Choosing a respective frame character e.g. '*' or '+' these lines will be enclosed by a frame:</p>
     *
     * <table class='goikTableDefaults'>
     *     <caption>Enclosing a text block by a frame.</caption>
     *     <tr>
     *         <th>Frame character <code>'*'</code></th>
     *         <th>Frame character <code>'+'</code></th>
     *     </tr>
     *     <tr>
     *         <td>
     * <pre> *********************
     * * This is           *
     * * just              *
     * * a couple of lines *
     * *********************</pre>
     *         </td>
     *         <td>
     * <pre> +++++++++++++++++++++
     * + This is           +
     * + just              +
     * + a couple of lines +
     * +++++++++++++++++++++</pre>
     *         </td>
     *     </tr>
     * </table>
     *
     * @param lines Lines to be printed.
     * @param frameCharacter The character to be used for drawing the frame i.e. '*' or '+'
     * @return A single multiline string representing a frame enclosed output.
     */
    public static String createFrame(final String[] lines, final char frameCharacter){

        // Get the maximum line length.
        int maxLineLength = 0;
        for (final String line : lines) {
            maxLineLength = Math.max(maxLineLength, line.length());
        }

        final StringBuilder sb = new StringBuilder();

        final String topAndBottomLine = Character.toString(frameCharacter).repeat(maxLineLength + 4);
        // Frame's top line
        sb.append(topAndBottomLine).append('\n');

        // Frame's intermediate lines
        for (String line : lines) {
            sb.append(frameCharacter).append(' ').append(line).
                    append(" ".repeat(maxLineLength - line.length() + 1)).append(frameCharacter).append('\n');
        }

        // Frame's bottom line
        sb.append(topAndBottomLine);
        return sb.toString();
    }

    private D_Frame(){/* Ignore me: My sole purpose is suppressing default constructor javadoc generation */}
}
